@@ -26,7 +26,11 @@ class TestDbtCliSolids:
             execute_solid(test_solid)
 
         failure: DagsterDbtCliFatalRuntimeError = exc.value
-        assert "Env var required but not provided:" in failure.metadata_entries[1].entry_data.text
+        expected_str = "Env var required but not provided:"
+        assert (
+            expected_str in str(failure.metadata_entries[0].entry_data.data)
+            or expected_str in failure.metadata_entries[1].entry_data.text
+        )
 
     def test_dbt_cli_run(
         self, dbt_seed, test_project_dir, dbt_config_dir
@@ -44,12 +48,7 @@ class TestDbtCliSolids:
             for event in result.step_events
             if event.event_type_value == "ASSET_MATERIALIZATION"
         ]
-        solid_materializations = [
-            materialization
-            for materialization in asset_materializations
-            if materialization.asset_key.path[0] == "dbt_run_cli_output"
-        ]
-        assert len(solid_materializations) == 1
+        assert len(asset_materializations) == 4
         table_materializations = [
             materialization
             for materialization in asset_materializations
@@ -150,8 +149,8 @@ class TestDbtCliSolids:
         result = execute_solid(test_solid)
         assert result.success
         assert any(
-            "Log macro: <<test succeded!>>" in log["message"]
-            for log in result.output_value()["logs"]
+            "Log macro: <<test succeded!>>" in log.get("message", log.get("msg", []))
+            for log in result.output_value("dbt_cli_output").logs
         )
 
     def test_dbt_cli_snapshot_freshness(
